@@ -2,6 +2,6 @@
 #ifndef MEDIAN1
 #define MEDIAN1
 
-int medianCpp(int x);
+int medianCpp(double x);
 
 #endif
